@@ -20,8 +20,8 @@ class Storage:
         """
         Provide the total RAM and free RAM to the user as a tuple
 
-        :rtype: tuple
-        :return: (Total, Free)
+        :rtype: tuple (int)
+        :return: (Total, Free)  Approximate bytes
 
         """
         output = subprocess.check_output(['free', '-m'])
@@ -29,23 +29,23 @@ class Storage:
         line = str(lines[1])
         ram = line.split()
         # total/free
-        return ram[1], ram[3]
+        return int(ram[1]), int(ram[3])
 
     @staticmethod
     def disc():
         """
         Provide the total disc space and the disc space that is free
 
-        :rtype: tuple
-        :return: (Total, Free)
+        :rtype: tuple (int)
+        :return: (Total, Free)  Approximate bytes
 
         """
-        output = subprocess.check_output(['df', '-h'])
+        output = subprocess.check_output(['df', '-k'])
         lines = output.splitlines()
         line = str(lines[1])
         disk = line.split()
         # total/free
-        return disk[1], disk[3]
+        return int(disk[1]*1024), int(disk[3]*1024)
 
     @staticmethod
     def all_discs():
@@ -58,7 +58,7 @@ class Storage:
 
         :return disc stats: dictionary of tuples
         """
-        disc_stats = {}
+        disc_stats = {'ERROR':"NOT IKMPLEMENTED"}
         # TODO: Create list of all drives and the total and free space for each
         # For each disc:
         #   obtain free space and total space
